<?php
/**
 * Виджет списка возвратов PayQR
 * PayQR Reverts grid container
 *
 *
 * @category   PayQR
 * @package    PayQR_Payment
 * @author     PayQR Team <api@payqr.ru>
 */
class PayQR_Payment_Block_Adminhtml_Revert_Grid extends Mage_Adminhtml_Block_Widget_Grid
{
    /**
     * Internal constructor
     * Внутренний констркутор
     */
    protected function _construct()
    {
        //вызов родитеского метода
        parent::_construct();
        //Установка id аттрибута
        $this->setId('payQRRevertGrid');
        //Сортировка по умолчанию по id и в прямом порядке
        $this->setDefaultSort('revert_id');
        $this->setDefaultDir('ASC');
    }

    /**
     * Prepare grid collection object
     * Подготовка коллекции возвратов
     * @return PayQR_Payment_Block_Adminhtml_Revert_Grid
     */
    protected function _prepareCollection()
    {
        // Определение коллекции
        /* @var $collection Mage_Widget_Model_Mysql4_Widget_Instance_Collection */
        $collection = Mage::getModel('payqr_payment/revert')->getCollection();
        // Если есть id заказа то фильтруем коллекцию по нему и одновляем информацию
        if ($this->getRequest()->getParam('order_id')){
            //Фильтр по order_id
            $collection->addFieldToFilter('magento_order_id',array("eq"=>$this->getRequest()->getParam('order_id')));
            foreach ($collection as $item){
                //Обновляем информацию по всем возвратам
                $sender = Mage::helper('payqr_payment/sender');
                $sender->updateRevertInfo($item);
            }
        }
        // Сохраняем коллекцию в блок
        $this->setCollection($collection);
        // Вызов родительского метода
        return parent::_prepareCollection();
    }

    /**
     * Prepare grid columns
     * Подготовка колонок списка
     * @return PayQR_Payment_Block_Adminhtml_Revert_Grid
     */
    protected function _prepareColumns()
    {
        // Создаем колонку ID
        $this->addColumn('revert_id', array(
            'header'    => Mage::helper('payqr_payment')->__('Revert ID'),
            'align'     => 'left',
            'index'     => 'revert_id',
            'width'     => '50px'
        ));

        //Создаем колонку номер заказа в системе PayQR
        $this->addColumn('payqr_order_id', array(
            'header'    => Mage::helper('payqr_payment')->__('PayQR ID'),
            'align'     => 'left',
            'index'     => 'payqr_order_id',

        ));

        // Создаем колонку сумма возврата
        $this->addColumn('amount', array(
            'header'    => Mage::helper('payqr_payment')->__('Amount'),
            'align'     => 'left',
            'index'     => 'amount',
            'width'     => '50px'
        ));


        //Создаем колонку статус
        $this->addColumn('status', array(
            'header'    => Mage::helper('payqr_payment')->__('Status'),
            'align'     => 'left',
            'index'     => 'status',
            'width'     => '100px',
            'type'      => 'options',
            //Получение опций
            'options'   => $this->getStatusOptionsArray()
        ));

        // Вызов родительского метода
        return parent::_prepareColumns();
    }

    /**
     * Retrieve array (widget_type => widget_name) of available widgets
     * Получение набора опция для столбца Status
     * @return array
     */
    public function getStatusOptionsArray()
    {
        //Инициализируем массив
        $status = array();
        //Добавляем возможные статусы
        $status['new'] = Mage::helper('payqr_payment')->__('New');
        $status['failed'] = Mage::helper('payqr_payment')->__('Failed');
        $status['succeeded'] = Mage::helper('payqr_payment')->__('Succeeded');
        //возвращаем массив
        return $status;
    }

}
