<?php

/**
 * PayQR system config url text renderer
 * Кнопки PayQR
 *
 * @category   PayQR
 * @package    PayQR_Payment
 * @author      PayQR Team <api@payqr.ru>
 *
 * @TODO: Обнулять корзину и показывать successpage после удачной покупки и закрытии окна.
 */
class PayQR_Payment_Block_Button extends Mage_Core_Block_Abstract
{
    /**
     * Метод генерирующий код кнопки на основе конфигурации модуля
     *
     * @return string
     */
    protected function _toHtml()
    {
        //проверяем можно ли показать кнопку
        if ($this->canShow()) {
            //формируем стандартные параметры кнопки
            $html = "<button ";
            $html .= 'data-scenario="buy" data-firstname-required="required" data-lastname-required="required" data-phone-required="required" ';
            if (Mage::getStoreConfig('payment/payqr/msg_enabled')){
                if ($msg_text = Mage::getStoreConfig('payment/payqr/msg_text')) {
                        $html .= 'data-message-text="'.$msg_text.'" ';
                }
                if ($msg_img_url = Mage::getStoreConfig('payment/payqr/msg_imageurl')) {
                        $html .= 'data-message-imageurl="'.$msg_img_url.'" ';
                }
                if ($msg_url = Mage::getStoreConfig('payment/payqr/msg_url')) {
                        $html .= 'data-message-url="'.$msg_url.'" ';
                }
            }
            $html .= 'data-email-required="required" data-delivery-required="required" ';
            //проверяем нужна ли доставка
            if ($this->_isNotVirtual())
                $html .= 'data-deliverycases-required="required" ';
            //добавляем аттрибуты data-cart и data-amount
            $html .= $this->_getDataCart();
            //добавляем стандартный класс
            $html .= 'class="payqr-button ';
            //добавляем классы в зависимости от настроек модуля
            //Цвет
            if ($this->_getConfigValue('color'))
                $html .= $this->_getConfigValue('color') . ' ';
            //Скругление
            if ($this->_getConfigValue('round'))
                $html .= $this->_getConfigValue('round') . ' ';
            //Градиент
            if ($this->_getConfigValue('gradient'))
                $html .= $this->_getConfigValue('gradient') . ' ';
            //Тень
            if ($this->_getConfigValue('shadow'))
                $html .= $this->_getConfigValue('shadow') . ' ';
            //Размер текста
            if ($this->_getConfigValue('fsize'))
                $html .= $this->_getConfigValue('fsize') . ' ';
            //Жирность текста
            if ($this->_getConfigValue('bold'))
                $html .= $this->_getConfigValue('bold') . ' ';
            //Регистр текста
            if ($this->_getConfigValue('upper'))
                $html .= $this->_getConfigValue('upper') . ' ';
            $html .= '"';
            //добавляем стиль кнопки для определения размера на основе конифгурации модуля
            $html .= 'style="';
            //ширина
            $html .= 'width:' . $this->_getConfigValue('width') . 'px;';
            //высота
            $html .= 'height:' . $this->_getConfigValue('height') . 'px';
            $html .= '"';
            $html .= '>' . $this->_getConfigValue('title') . '</button>';
            return $html;
        } else {
            return '';
        }

    }

    /**
     * Получаем тип кнопки
     *
     * - cart_button - кнопка в корзине (по умолчанию)
     * - product_button - кнопка в карточке товаров
     * - catalog_button - кнопка в списке товаров
     *
     * @return mixed|string
     */

    public function getType()
    {
        //Если указан тип кнопки то возвращаем его значение
        if ($this->getData('button_type')) {
            return $this->getData('button_type');
            //Если нет то "cart_button"
        } else {
            return "cart_button";
        }
    }

    /**
     * Проверка включено ли отображение данного вида кнопки
     *
     * @return bool|mixed
     *
     */
    public function canShow()
    {
        //Получаем тип кнопки
        $type = $this->getType();

        switch ($type) {
            //Если "cart_button" проверяем включен ли модуль
            case ("cart_button") :
                return Mage::getStoreConfig('payment/payqr/active');
            //Если "product_button" проверяем включено ли отображение кнопки на карточке товара
            case ("product_button") :
                return (Mage::getStoreConfig('payment/payqr/customize_product_button') && Mage::getStoreConfig('payment/payqr/active'));
            default:
                return false;
        }

    }

    /**
     * Формирование аттрибутов data-cart и data-amount
     *
     * @return string
     */
    protected function _getDataCart()
    {
        $str = "data-cart='";
        //Получение типа кнопки
        switch ($this->getType()) {
            //тип кнопки cart-button
            case "cart_button":

                //получаем все позиции корзины
                $cart_items = Mage::getSingleton("checkout/cart")->getQuote()->getAllVisibleItems();
                //создаем пустой массив для формирования data-cart в формате json
                $data_cart = array();
                //получаем размер картинки из конфига
                $image_size = Mage::getStoreConfig("payment/payqr/cartitem_imagesize");
                //перебираем все позиции корзины
                foreach ($cart_items as $cart_item) {
                    //формируем строку атрибута data-cart в нужном формате
                    //получаем значение article (артикул)
                    $item['article'] = $cart_item->getSku();
                    //получаем значение name (название позиции)
                    $item['name'] = $cart_item->getName();
                    //получаем значение amount (стоимость позиции)
                    $item['amount'] = (string)$cart_item->getRowTotal();
                    //получаем значение quantity (количество)
                    $item['quantity'] = (string)$cart_item->getQty();
                    //получаем значение imageurl (адрес изображения)
                    $item['imageUrl'] = $this->helper('catalog/image')->init($cart_item->getProduct(), 'thumbnail')->resize($image_size)->__toString();
                    $data_cart[] = $item;
                }
                //кодируем php-массив в JSON формат и добавляем в строку
                $str .= Zend_Json::encode($data_cart);
                //добавляем значение общей суммы корзины с учетом всех скидок и наценок.
                $str .= "' data-amount='" . Mage::getSingleton("checkout/cart")->getQuote()->getGrandTotal() . "' ";
                $str .= "data-ordergroup='" . Mage::getSingleton("checkout/cart")->getQuote()->getId() . "' ";
                break;
            //тип кнопки product-button
            case "product_button":
                //Получаем продукт
                $product = Mage::registry('current_product');
                //создаем пустой массив для формирования data-cart в формате json
                $data_cart = array();
                //получаем размер картинки из конфига
                $image_size = Mage::getStoreConfig("payment/payqr/cartitem_imagesize");
                //формируем строку атрибута data-cart в нужном формате
                //получаем значение article (артикул)
                $item['article'] = $product->getSku();
                //получаем значение name (название позиции)
                $item['name'] = $product->getName();
                //получаем значение amount (стоимость позиции)
                $item['amount'] = $product->getPrice();
                //получаем значение quantity (количество)
                $item['quantity'] = 1;
                //получаем значение imageurl (адрес изображения)
                $item['imageUrl'] = $this->helper('catalog/image')->init($product, 'thumbnail')->resize($image_size)->__toString();
                $data_cart[] = $item;
                //кодируем php-массив в JSON формат и добавляем в строку
                $str .= Zend_Json::encode($data_cart);
                //добавляем значение общей суммы корзины с учетом всех скидок и наценок.
                $str .= "' data-amount='" . $product->getPrice() . "' ";
                $str .= "data-ordergroup='" . Mage::getSingleton("checkout/cart")->getQuote()->getId() . "' ";
                break;
        }
        return $str;
    }

    /**
     * Получение значения параметров кнопки из конфига на основе типа кнопки
     *
     * @param $key
     * @return mixed
     *
     */
    protected function _getConfigValue($key)
    {
        return Mage::getStoreConfig('payment/payqr/' . $this->getType() . "_" . $key);
    }

    /**
     * Проверка нужна ли доставка
     *
     * @return bool
     */

    protected function _isNotVirtual()
    {
        //по умолчанию доставка нужна
        $result = true;
        switch ($this->getType()) {
            //тип кнопки cart-button
            case "cart_button":
                //проверяем виртуальная ли корзина
                $result = !Mage::getSingleton("checkout/cart")->getQuote()->isVirtual();
                break;
            //тип кнопки product-button
            case "product_button":
                /** @var Mage_Catalog_Model_Product $product */
                //получаем текущий продукт
                $product = Mage::registry('current_product');
                //проверяем виртуален ли продукт
                $result = !$product->isVirtual();
                break;
        }
        //Возвращаем результат
        return $result;
    }
}