<?php

//Инициализируем автозагрузчик классов payQR
if (!defined('PAYQR_ROOT')) {
    define('PAYQR_ROOT', MAGENTO_ROOT . DS . 'payqr' . DS);
    require_once(PAYQR_ROOT . 'classes' . DS . 'payqr_autoload.php');
}
//Устанавливаем пути для обработчиков ответов от PayQR API и ошибок
if (!defined('PAYQR_ERROR_HANDLER')) {
    define('PAYQR_ERROR_HANDLER', PAYQR_ROOT . DS . 'handlers_errors' . DS);
}
if (!defined('PAYQR_HANDLER')) {
    define('PAYQR_HANDLER', PAYQR_ROOT . DS .  'handlers' . DS);
}

//Загружаем конфиг PayQR
require_once PAYQR_ROOT . 'payqr_config.php';
date_default_timezone_set("Europe/Moscow");

/**
 * PayQR Sender
 * Хелпер для отпарвки сообщений на сервер PayQR API
 *
 * @category   PayQR
 * @package    PayQR_Payment
 * @author     PayQR Team <api@payqr.ru>
 */
class PayQR_Payment_Helper_Sender extends Varien_Object
{
    /**
     * @var payqr_invoice_action
     */
    protected $_invoice_action;
    /**
     * @var payqr_revert_action
     */
    protected $_reverts_action;

    /**
     * Инициализируем объект
     */
    public function __construct()
    {
        //Инициализируем объекты классов для отправки запросов на сервер PayQR API
        $this->_invoice_action = new payqr_invoice_action();
        $this->_reverts_action = new payqr_revert_action();
        //Вызываем родительский метод
        return parent::__construct();
    }

    /**
     * Метод для отправки запроса на отмену заказа
     * @param PayQR_Payment_Model_Order $payqr_order
     * @return mixed|string
     */
    public function sendCancelRequest(PayQR_Payment_Model_Order $payqr_order)
    {
        //Устанавливаем комментарий к заказу
        $payqr_order->setComment(Mage::helper('payqr_payment')->__('Cancel request send. Refresh page after minute, please.'));
        //Сохраняем заказ
        $payqr_order->save();
        //Возвращаем результат запроса
        return $this->_invoice_action->invoice_cancel($payqr_order->getPayqrOrderId());
    }

    /**
     * Метод для отправки запроса на отмену заказа
     * @param PayQR_Payment_Model_Order $payqr_order
     * @param $amount
     * @return mixed|string
     */
    public function sendRevertRequest(PayQR_Payment_Model_Order $payqr_order, $amount)
    {
        //Возвращаем результат запроса
        return $this->_invoice_action->invoice_revert($payqr_order->getPayqrOrderId(),$amount);
    }

    /**
     * Метод для отправки запроса на подтверждения заказа
     * @param PayQR_Payment_Model_Order $payqr_order
     * @return mixed|string
     */
    public function sendConfirmRequest(PayQR_Payment_Model_Order $payqr_order)
    {
        //Возвращаем результат запроса
        return $this->_invoice_action->invoice_confirm($payqr_order->getPayqrOrderId());
    }

    /**
     * Метод для отправки запроса на подтверждения заказа
     * @param PayQR_Payment_Model_Order $payqr_order
     * @return mixed|string
     */
    public function sendExecutionConfirmRequest(PayQR_Payment_Model_Order $payqr_order)
    {
        //Возвращаем результат запроса
        return $this->_invoice_action->invoice_execution_confirm($payqr_order->getPayqrOrderId());
    }

    /**
     * Метод чтобы дослать/изменить сообщение
     *
     * @param PayQR_Payment_Model_Order $payqr_order
     * @param $message
     * @return mixed|string
     * @throws Exception
     */
    public function sendInvoiceMessage(PayQR_Payment_Model_Order $payqr_order, $message)
    {
        //Проверяем сообщение на пустоту
        if ($message)
            //Возвращаем результат запроса
            return $this->_invoice_action->invoice_message($payqr_order->getPayqrOrderId(), $message);
        else
            //Выбрасываем исключение
            throw new Exception("Message is empty");
    }

    /**
     * Метод для получение актульных данных по заказу
     *
     * @param PayQR_Payment_Model_Order $payqr_order
     * @return PayQR_Payment_Model_Order
     */
    public function updateInvoiceInfo(PayQR_Payment_Model_Order $payqr_order){
        //Получаем актульные данные от PayQR API
        $json = $this->_invoice_action->get_invoice($payqr_order->getPayqrOrderId());
        //Сохраняем данные в модель заказа PayQR
        $payqr_order->setInvoiceObject(json_decode($json));
        //Обновляем модель
        $payqr_order->update();
        //Возвращаем модель
        return $payqr_order;
    }

    /**
     * Метод для получение актульных данных по возврату
     * @param PayQR_Payment_Model_Revert $payqr_revert
     * @return PayQR_Payment_Model_Revert
     */
    public function updateRevertInfo(PayQR_Payment_Model_Revert $payqr_revert){
        //Получаем актульные данные от PayQR API
        $json = $this->_reverts_action->get_revert($payqr_revert->getPayqrRevertId());
        //Обновляем модель возврата
        $payqr_revert->update(json_decode($json));
        //Возвращаем модель
        return $payqr_revert;
    }
}
