<?php

/**
 * Observer PayQR
 * Обозреватель PayQR
 *
 * @category   PayQR
 * @package    PayQR_Payment
 * @author     PayQR Team <api@payqr.ru>
 *
 */
class PayQR_Payment_Model_Observer
{

    /**
     * Запрос в PayQR API при создании возврата в Magento
     * @param Varien_Event_Observer $observer
     */
    public function revertByCreditmemo(Varien_Event_Observer $observer)
    {
        try {
            //Получаем текущий контроллер
            /* @var $action Mage_Core_Controller_Varien_Action */
            $action = $observer->getData('controller_action');
            //Получаем модель возврата Magento
            /* @var $creditmemo Mage_Sales_Model_Order_Creditmemo */
            $creditmemo = Mage::registry('current_creditmemo');
            //Получаем модель сессии
            /* @var $session Mage_Adminhtml_Model_Session */
            $session = Mage::getSingleton('adminhtml/session');
            //Если нет ошибок в сессии
            if (!count($session->getMessages()->getErrors())) {
                //Получаем объект для отправки
                $sender = Mage::helper('payqr_payment/sender');
                //Загрузить модель PayQR заказа
                $payqr_order = Mage::getModel('payqr_payment/order')->loadByOrderId($creditmemo->getOrderId());
                //Отправляем запрос на возврат
                $sender->sendRevertRequest($payqr_order, $creditmemo->getGrandTotal());
            }
        } catch (Exception $e) {
            //Логируем исключение
            Mage::logException($e);
        }
    }

    /**
     * Запрос в PayQR API при полностью завершенном заказе
     * @param Varien_Event_Observer $observer
     */
    public function salesOrderSaveBeforeOrderSave(Varien_Event_Observer $observer)
    {
        //Получаем текущий заказ
        /** @var Mage_Sales_Model_Order $order */
        $order = $observer->getData('order');
        //Если заказ полностью выполнен
        if ($order->getStatus() == Mage_Sales_Model_Order::STATE_COMPLETE) {
            //Получаем объект для отправки
            $sender = Mage::helper('payqr_payment/sender');
            //Загрузить модель PayQR заказа
            $payqr_order = Mage::getModel('payqr_payment/order')->loadByOrderId($order->getId());
            //Отправляем запрос на возврат
            $sender->sendExecutionConfirmRequest($payqr_order);
        }
    }

}