<?php

/**
 * Model PayQR Order
 * Модель, описывающая заказ PayQR
 *
 * @category   PayQR
 * @package    PayQR_Payment
 * @author     PayQR Team <api@payqr.ru>
 *
 *
 * @method PayQR_Payment_Model_Order setPayqrData(string $serial)
 * @method string getPayqrData()
 * @method PayQR_Payment_Model_Order setPayqrNumber(string $id)
 * @method string getPayqrNumber()
 * @method PayQR_Payment_Model_Order setPayqrOrderId(string $id)
 * @method string getPayqrOrderId()
 * @method PayQR_Payment_Model_Order setMagentoOrderId(string $id)
 * @method string getMagentoOrderId()
 * @method PayQR_Payment_Model_Order setStatus(string $status)
 * @method string getStatus()
 * @method PayQR_Payment_Model_Order setComment(string $status)
 * @method string getComment()
 */
class PayQR_Payment_Model_Order extends Mage_Core_Model_Abstract
{
    /**
     * @var PayQR_Payment_Model_Order
     */
    protected $_payqr_obj;


    /**
     * Инициализация модели
     * @void
     */
    protected function _construct()
    {
        //Устанавливаем модель-ресурс
        $this->_init('payqr_payment/order');
        //Вызываем родительский метод
        parent::_construct();
    }

    /**
     * Загружаем данные по ID заказ в Magento
     * @param $id
     * @return $this
     */
    public function loadByOrderId($id)
    {
        //Загружаем модель через коллекцию и фильтр по Magento Order ID
        $this->load($this->getCollection()->addFieldToFilter('magento_order_id', array('eq' => $id))->getFirstItem()->getId());
        //возвращаем модель
        return $this;
    }

    /**
     * Получаем объект данных PayQR Invoice
     * @return mixed|PayQR_Payment_Model_Order
     */
    public function getInvoiceObject()
    {
        //Если объект не сохранен в модели
        if (!$this->_payqr_obj)
            //Формируем объект и сохраняем в модель
            $this->_payqr_obj = unserialize($this->getPayqrData());

        //Возвращаем объект данных
        return $this->_payqr_obj;
    }

    /**
     * Устанавливаем объект данных PayQR Invoice
     * @param $obj
     * @return $this
     */
    public function setInvoiceObject($obj)
    {
        //Сохраняем в модель
        $this->_payqr_obj = $obj;
        //Возвращаем объект данных
        return $this;
    }

    /**
     * Перед сохранением модели
     * @return Mage_Core_Model_Abstract
     */
    public function _beforeSave()
    {
        //Устанавливаем сериализованные данные в модель
        $this->setPayqrData(serialize($this->getInvoiceObject()));
        //Вызываем родительский метод
        return parent::_beforeSave();
    }

    /**
     * Обновляем модель
     * @return $this
     */
    public function update()
    {
        //Получаем текущий статус заказа PayQR
        $old_status = $this->getStatus();
        //Устанавливаем новый статус из объекта данных
        //$this->_payqr_obj = unserialize($this->getPayqrData());
        $this->setStatus($this->_payqr_obj->status);
        //Проверяем статус
        if ($this->getStatus() == "failed" || $this->getStatus() == "cancelled") {
                //Загружаем заказ Magento
                $magentoOrder = Mage::getModel('sales/order')->load($this->getMagentoOrderId());
                //Отменяем заказ
                $magentoOrder->cancel();
        } else if ($this->getStatus() == "reverted") {
				$order = Mage::getModel('sales/order')->load($this->getMagentoOrderId());
				//Отменяем заказ
				$order->cancel();
					$order->save();
                //Если есть созданные счета
				if ($order->hasInvoices() && $order->getStatus() != Mage_Sales_Model_Order::STATE_CANCELED)
				{
					
					
					//Загружаем сервис
					$service = Mage::getModel('sales/service_order', $order);
					//Перебираем счета заказа
					foreach ($order->getInvoiceCollection() as $invoice) {
						//Формируем отмену заказа
						$creditmemo = $service->prepareInvoiceCreditmemo($invoice);
						//Регистриуем отмену заказа
						$creditmemo->register();
						//Сохраняем
						$creditmemo->save();
						}
						
						//Отменяем заказ
						
        		}
        }
        //Сохраняем
        $this->save();
        //Возвращаем модель
        return $this;
    }
}