<?php

/**
 * Admihtml Manage PayQR Orders Controller
 * Контроллер отвечающий за действия над Заказами и Возвратами в интерфейсе админпанели
 *
 * @category   PayQR
 * @package    PayQR_Payment
 * @author     PayQR Team <api@payqr.ru>
 */
class PayQR_Payment_Adminhtml_PayqrController extends Mage_Adminhtml_Controller_Action
{

    /**
     * Session getter
     * Получение объекта сессии админпанели
     *
     * @return Mage_Adminhtml_Model_Session
     */
    protected function _getSession()
    {
        return Mage::getSingleton('adminhtml/session');
    }

    /**
     * Load layout, set active menu and breadcrumbs
     * Загрузка вывода, установка активных пунктов меню формирование хлебных крошек
     *
     * @return PayQR_Payment_Adminhtml_PayqrController
     */
    protected function _initAction()
    {
        //Получаем объект вывода
        $this->loadLayout()
            //Устанавливаем активный пункт меню
            ->_setActiveMenu('payqr_payment/orders')
            //Формируем хлебные крошки
            ->_addBreadcrumb(Mage::helper('payqr_payment')->__('PayQR'),
                Mage::helper('payqr_payment')->__('PayQR'))
            ->_addBreadcrumb(Mage::helper('payqr_payment')->__('PayQR Orders'),
                Mage::helper('payqr_payment')->__('PayQR Orders'));
        return $this;
    }

    /**
     * PayQR Revert Grid
     * Действие для отображения списка заказов PayQR
     */
    public function indexAction()
    {
        //Установка загаловка страницы
        $this->_title($this->__('payqr_payment'))->_title($this->__('PayQR Reverts'));
        //Загрузка и прорисовка вывода (страницы)
        $this->_initAction()
            ->renderLayout();
    }

    /**
     * Дейстие для отмены заказа
     */
    public function cancelAction()
    {
        try {
            //Устанавлием значение ответа по умолчанию
            $response = false;
            //Получаем текущий PayQR заказ
            $payqr_order = $this->_getPayqrOrder();
            //Инициализируем sender
            $sender = Mage::helper('payqr_payment/sender');
            //Отправляем запрос на отмену
            $sender->sendCancelRequest($payqr_order);
            //Загружаем "пустой" шаблон
            $this->loadLayout('empty');
            //Формируем ответ
            $this->renderLayout();
        } catch (Exception $e) {
            //Если произошла ошибка, формируем ответ, содержащий сообщение об ошибке
            $response = array(
                'error' => true,
                'message' => $e->getMessage()
            );
        }
        //Если ответ ошибочен, возвращаем json ответ
        if (is_array($response)) {
            $response = Mage::helper('core')->jsonEncode($response);
            $this->getResponse()->setBody($response);
        }
    }

    /**
     * Дейстие для отмены заказа
     */
    public function updateAction()
    {
        try {
            //Устанавлием значение ответа по умолчанию
            $response = false;
            //Получаем текущий PayQR заказ
            $payqr_order = $this->_getPayqrOrder();
            //Инициализируем sender
            $sender = Mage::helper('payqr_payment/sender');
            //Обновляем информацию о заказе
            $sender->updateInvoiceInfo($payqr_order);
            //Загружаем "пустой" шаблон
            $this->loadLayout('empty');
            //Формируем ответ
            $this->renderLayout();
        } catch (Exception $e) {
            //Если произошла ошибка, формируем ответ, содержащий сообщение об ошибке
            $response = array(
                'error' => true,
                'message' => $e->getMessage()
            );
        }
        //Если ответ ошибочен, возвращаем json ответ
        if (is_array($response)) {
            $response = Mage::helper('core')->jsonEncode($response);
            $this->getResponse()->setBody($response);
        }
    }

    public function messageAction()
    {
        try {
            //Устанавлием значение ответа по умолчанию
            $response = false;
            //Проверяем пустое ли поле сообщения
            if ($message = $this->getRequest()->getParam('payqr_message')) {
                //Получаем текущий PayQR заказ
                $payqr_order = $this->_getPayqrOrder();
                //Инициализируем sender
                $sender = Mage::helper('payqr_payment/sender');
                //Отправляем запрос на измение/добавление сообщения к заказу
                $sender->sendInvoiceMessage($payqr_order, $message);
                //Загружаем "пустой" шаблон
                $this->loadLayout('empty');
                //Формируем ответ
                $this->renderLayout();
            } else {
                //Если поле сообщения пустое выбрасываем исключение
                throw new Exception("Message is empty");
            }
        } catch (Exception $e) {
            //Если произошла ошибка, формируем ответ, содержащий сообщение об ошибке
            $response = array(
                'error' => true,
                'message' => $e->getMessage()
            );
        }
        //Если ответ ошибочен, возвращаем json ответ
        if (is_array($response)) {
            $response = Mage::helper('core')->jsonEncode($response);
            $this->getResponse()->setBody($response);
        }
    }


    /**
     * Метод для получения текущего заказа PayQR
     *
     * @return PayQR_Payment_Model_Order
     * @throws Exception
     */
    protected function _getPayqrOrder()
    {
        //Загружаем модель заказа по id из запроса
        $payqr_order = Mage::getModel("payqr_payment/order")->load($this->getRequest()->getParam('id', null));
        if (!$payqr_order->getId()) {
            //Если загрузить модель не удалось, выбрасываем исключение
            throw new Exception("Can't load PayQR Order");
        }
        //Сохраняем текущий PayQR заказ в реестр
        Mage::register('current_payqrorder', $payqr_order);
        //Возвращаем текущий PayQR заказ
        return $payqr_order;
    }
}