<?php
/**
 * Код в этом файле будет выполнен, когда интернет-сайт получит уведомление от PayQR о необходимости предоставить покупателю способы доставки конкретного заказа.
 * Это означает, что интернет-сайт на уровне кнопки PayQR активировал этап выбора способа доставки покупателем, и сейчас покупатель дошел до этого этапа.
 *
 * $Payqr->objectOrder содержит объект "Счет на оплату" (подробнее об объекте "Счет на оплату" на https://payqr.ru/api/ecommerce#invoice_object)
 *
 * Ниже можно вызвать функции своей учетной системы, чтобы особым образом отреагировать на уведомление от PayQR о событии invoice.deliverycases.updating.
 *
 * Важно: на уведомление от PayQR о событии invoice.deliverycases.updating нельзя реагировать как на уведомление о создании заказа, так как иногда оно будет поступать не от покупателей, а от PayQR для тестирования доступности функционала у конкретного интернет-сайта, т.е. оно никак не связано с реальным формированием заказов. Также важно, что в ответ на invoice.deliverycases.updating интернет-сайт может передать в PayQR только содержимое параметра deliveryCases объекта "Счет на оплату". Передаваемый в PayQR от интернет-сайта список способов доставки может быть многоуровневым.
 *
 * Пример массива способов доставки:
 * $delivery_cases = array(
 *          array(
 *              'article' => '2001',
 *               'number' => '1.1',
 *               'name' => 'DHL',
 *               'description' => '1-2 дня',
 *               'amountFrom' => '0',
 *               'amountTo' => '70',
 *              ),
 *          .....
 *  );
 * $Payqr->objectOrder->setDeliveryCases($delivery_cases);
 */

//Получаем данные заказа PayQR
// id корзины
$quoteId = $Payqr->objectOrder->getOrderGroup();
// клиент
$customer = $Payqr->objectOrder->getCustomer();
// адрес доставки
$delivery = $Payqr->objectOrder->getDelivery();

//Инизиализируем корзину
$quote = Mage::getSingleton("sales/quote")->load($quoteId);

//Формируем массив данных
$data = array();
//Имя
$data['firstname'] = $customer->firstName;
//Фамилия
$data['lastname'] = $customer->lastName;
//Email
$data['email'] = $customer->email;
//Страна (Всегда RU - Россия)
$data['country_id'] = "RU";
//Регион
$data['region'] = $delivery->region;
//Город
$data['city'] = $delivery->city;
//Индекс
$data['postcode'] = $delivery->zip;
//Телефон
$data['telephone'] = $customer->phone;
//Формируем строку улицы
$data['street'] = $delivery->street . " " . $delivery->house;
//Добавляем корпус
if ($delivery->unit)
    $data['street'] .= " корп. " . $delivery->unit;
//строение
if ($delivery->building)
    $data['street'] .= " стр. " . $delivery->building;
//квартиру
if ($delivery->flat)
    $data['street'] .= " кв. " . $delivery->flat;
//Инициализируем и наполняем данными адреса плательщика и доставки у нас они совпадают
//Адрес плательщика
$billingAddress = $quote->getBillingAddress()->addData($data);
//Доставка
$shippingAddress = $quote->getShippingAddress()->addData($data);
//Пересчитываем стоимости доставок
$shippingAddress->setCollectShippingRates(true)->collectShippingRates();
//Заполняем данные пользователя (пока только как гостя)
$quote->setCustomerId(null)
//email
    ->setCustomerEmail($quote->getBillingAddress()->getEmail())
//Гость? да
    ->setCustomerIsGuest(true)
//Группа пользователя
    ->setCustomerGroupId(Mage_Customer_Model_Group::NOT_LOGGED_IN_ID);
//Пресчитываем итого, сохраняем корзину
$quote->collectTotals()->save();

//Получаем все методы доставки на основе адреса
$groups = $quote->getShippingAddress()->getGroupedAllShippingRates();

//Инициализируем переменные для формирования списка методов доставки
$delivery = array();
$deliveryCases = array();
$group_iter = 1;

//Перебираем все методы доставки
foreach ($groups as $code => $rates) {
    //Формируем и сохроняем основной пункт меню
  /*  $deliveryCases[] = array(
        "article" => (string)$group_iter,
        "number" => (string)$group_iter,
        "name" => Mage::getStoreConfig('carriers/' . $code . '/title'),
        "description" => "",
        "amountFrom" => "1000000000000"
    );
  */
    //Перебираем подпункты меню
    foreach ($rates as $child_iter => $rate) {
        //Формируем подпункт меню
        $delivery_child_item = array(
            "article" => $rate->getCode(),
            "number" => $group_iter . "." . ($child_iter+1),
            "name" => Mage::getStoreConfig('carriers/' . $code . '/title')." ".(string)$rate->getMethodTitle(),
            "description" => (string)$rate->getMethodDescription(),
            "amountFrom" => (string)$rate->getPrice(),
            "amountTo" => (string)$rate->getPrice()
        );
        
        $deliveryCases[] = $delivery_child_item;
    }
    //счетчик итераций
    $group_iter++;
}
//Устанавливаем список методов доставок
$Payqr->objectOrder->setDeliveryCases($deliveryCases);