<?php
/**
 * Код в этом файле будет выполнен, когда интернет-сайт получит уведомление от PayQR о сбое в совершении покупки (завершении операции).
 * Это означает, что что-то пошло не так в процессе совершения покупки (например, интернет-сайт не ответил во время на уведомление от PayQR), поэтому операция прекращена.
 *
 * $Payqr->objectOrder содержит объект "Счет на оплату" (подробнее об объекте "Счет на оплату" на https://payqr.ru/api/ecommerce#invoice_object)
 *
 * Ниже можно вызвать функции своей учетной системы, чтобы особым образом отреагировать на уведомление от PayQR о событии invoice.failed.
 *
 * Получить orderId из объекта "Счет на оплату", по которому произошло событие, можно через $Payqr->objectOrder->getOrderId();
 */

//Получаем order_id
$order_id = $Payqr->objectOrder->getOrderId();
//Если указан order_id
if ($order_id) {
    //Загружаем заказ PayQR по id Magento заказа
    $payqr_order = Mage::getModel('payqr_payment/order')->loadByOrderId($order_id);
    //Загружаем заказ Magento
    $order = Mage::getModel('sales/order')->load($order_id);
//Если order_id не указан
} else {
    //Получаем payqr_number
    $payqr_order_id = $Payqr->objectOrder->getPayqrNumber();
    //Загружаем заказ PayQR по payqr_number
    $payqr_order = Mage::getModel('payqr_payment/order')->getCollection()->addFieldToFilter('payqr_number',array('eq'=>$payqr_order_id))->getFirstItem();
    //Загружаем заказ Magento
    $order = Mage::getModel('sales/order')->load($payqr_order->getMagentoOrderId());
}
//Если заказ PayQR загружен
if ($payqr_order->getId()) {
    //Если заказ Magento не отменен
    if ($order->getState() != Mage_Sales_Model_Order::STATE_CANCELED)
        //Отменяем заказ Magento
        $order->cancel()->save();

    //Устанавливаем статус PayQR заказа
    $payqr_order->setStatus("failed")
            //Устанавливаем данные в PayQR заказ
            ->setPayqrData(serialize($Payqr->objectEvent->data))
            ->setComment('')
             //Сохраняем PayQR заказ
            ->save();
//Если PayQR заказ не удалось загружить
} else {
    //Выкидываем исключение
    throw new Exception("PayQR order isn't exist for this order ID.");
}