<?php
/**
 * Код в этом файле будет выполнен, когда интернет-сайт получит уведомление от PayQR об успешной оплате конкретного заказа.
 * Это означает, что PayQR успешно списал запрошенную интернет-сайтом сумму денежных средств с покупателя и перечислит ее интернет-сайту в ближайшее время, интернет-сайту нужно исполнять свои обязанности перед покупателем, т.е. доставлять товар или оказывать услугу.
 *
 * $Payqr->objectOrder содержит объект "Счет на оплату" (подробнее об объекте "Счет на оплату" на https://payqr.ru/api/ecommerce#invoice_object)
 *
 * Ниже можно вызвать функции своей учетной системы, чтобы особым образом отреагировать на уведомление от PayQR о событии invoice.paid.
 *
 * Получить orderId из объекта "Счет на оплату", по которому произошло событие, можно через $Payqr->objectOrder->getOrderId();
 *
 * Важно: несмотря на то, что заказ создается на этапе получения уведомления о событии invoice.order.creating, крайне рекомендуется валидировать все содержание заказа и после получения уведомления о событии invoice.paid. А в случае, когда запрос адреса доставки у покупателя на уровне кнопки PayQR, настроен на рекомендательный режим (спрашивать после оплаты/спрашивать необязательно), то не просто рекомендуется, а обязательно, так как объект "Счет на оплату" на этапе invoice.paid будет содержать в себе расширенные окончательные данные, которых не было на invoice.order.creating. Если по результатам проверки данных из invoice.paid обнаружатся какие-то критичные расхождения (например, сумма заказа из объекта "Счет на оплату" не сходится с суммой из соответствующего заказа), можно сразу послать запрос в PayQR на отмену счету после его оплаты (возврат денег).
 */
//Статус заказа при подтверждении оплаты
$state = Mage_Sales_Model_Order::STATE_PROCESSING;
//Загружаем заказ
$order = Mage::getModel('sales/order')->load($Payqr->objectOrder->getOrderId());
//Загружаем корзину
$quoteId = $order->getQuoteId();
$quote = Mage::getModel("sales/quote")->load($quoteId);
//Удаляем корзину
$quote->setIsActive(false);
$quote->delete();
//Получаем PayQR заказ
$payqr_order = Mage::getModel('payqr_payment/order')->loadByOrderId($order->getId());
//Если проверяем статус заказ
Mage::log($order->getState(),null,"testing.log");
if ($order->getState() == Mage_Sales_Model_Order::STATE_PENDING_PAYMENT || $order->getState() == Mage_Sales_Model_Order::STATE_NEW) {
	Mage::log($order->getGrandTotal(),null,"testing.log");
	Mage::log($Payqr->objectOrder,null,"testing.log");
	Mage::log((float)$Payqr->objectOrder->getAmount());
        if ((float)$order->getGrandTotal() != (float)$Payqr->objectOrder->getAmount()){
           $sender = Mage::helper('payqr_payment/sender')->sendRevertRequest($payqr_order,$payqr_order->getInvoiceObject()->amount);
           $order->cancel()->save();
        } else {
        //Если можем создаем счет на оплату
        if ($order->canInvoice()) {
            //подготавливаем счет
            $invoice = $order->prepareInvoice();
            //регистрируем, оплачиваем счет
            $invoice->register()->capture();
            //связываем счет с заказом
            $order->addRelatedObject($invoice);
        }
        //Устанавливаем статус заказа
        $order->setState($state,
            "processing",
            //Добавляем комментарий
            Mage::helper('payqr_payment')->__('The amount has been authorized and captured by PayQR. Invoice PayQR Id. %s',$Payqr->objectOrder->getPayqrNumber()),
            true);
        //Сохраняем заказ
        $order->save();
        //Обновляем информацию по заказу
        $sender = Mage::helper('payqr_payment/sender');
        $sender->updateInvoiceInfo($payqr_order);
        }
}
