<?php
/**
 * Код в этом файле будет выполнен, когда интернет-сайт получит уведомление от PayQR о полной отмене счета (заказа) после его оплаты.
 * Это означает, что посредством запросов в PayQR интернет-сайт либо одной полной отменой, либо несколькими частичными отменами вернул всю сумму денежных средств по конкретному счету (заказу).
 *
 * $Payqr->objectOrder содержит объект "Счет на оплату" (подробнее об объекте "Счет на оплату" на https://payqr.ru/api/ecommerce#invoice_object)
 *
 * Ниже можно вызвать функции своей учетной системы, чтобы особым образом отреагировать на уведомление от PayQR о событии invoice.reverted.
 *
 * Получить orderId из объекта "Счет на оплату", по которому произошло событие, можно через $Payqr->objectOrder->getOrderId();
 */
/* @var $order Mage_Sales_Model_Order */
//Получаем order_id
$order_id = $Payqr->objectOrder->getOrderId();
//Загружаем заказ Magento
$order = Mage::getModel('sales/order')->load($order_id);
//Загружаем заказ PayQR по id Magento заказа
$payqr_order = Mage::getModel('payqr_payment/order')->loadByOrderId($order_id);
//Проверяем загружен ли заказ Magento
if ($order->getId()) {
    //Если есть созданные счета
    if ($order->hasInvoices())
    {
        //Если заказ не отменен
        if ($order->getState() != Mage_Sales_Model_Order::STATE_CANCELED) {
            //Отменяем заказ
            $order->cancel();
        }
        //Устанавлием статус payQR заказа
        $payqr_order->setStatus("reverted")
            //Устанавливаем данные в PayQR заказ
            ->setPayqrData(serialize($Payqr->objectEvent->data))
            //Сохраняем PayQR заказ
            ->save();
        //Загружаем сервис
        $service = Mage::getModel('sales/service_order', $order);
        //Перебираем счета заказа
        foreach ($order->getInvoiceCollection() as $invoice) {
            //Формируем отмену заказа
            $creditmemo = $service->prepareInvoiceCreditmemo($invoice);
            //Регистриуем отмену заказа
            $creditmemo->register();
            //Сохраняем
            $creditmemo->save();
        }
        //Загружаем модель PayQR заказа
        $payqr_revert = Mage::getModel('payqr_payment/revert')
            //Записываем номер заказа в PayQR системе
            ->setPayqrNumber($Payqr->objectOrder->getPayqrNumber())
            //Записываем идентификатор заказа PayQR
            ->setPayqrOrderId($Payqr->objectOrder->getInvId())
            //Записываем номер заказа в Magento
            ->setMagentoOrderId($order->getId())
            //Записываем рамер возврата
            ->setAmount($Payqr->objectOrder->getAmount())
            //Сохраняем
            ->save();
    }
}